@@ -1,7 +1,7 @@
 // qsynthAbout.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -13,9 +13,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -29,7 +29,9 @@
 
 #define QSYNTH_SUBTITLE     "A fluidsynth Qt GUI Interface"
 #define QSYNTH_WEBSITE      "http://qsynth.sourceforge.net"
-#define QSYNTH_COPYRIGHT    "Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved."
+#define QSYNTH_COPYRIGHT    "Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved."
+
+#define QSYNTH_DOMAIN       "rncbc.org"
 
 #endif  // __qsynthAbout_h
 
