@@ -33,6 +33,10 @@
 #include "qsynthMessagesForm.h"
 #include "qsynthChannelsForm.h"
 
+#include "qsynthDialClassicStyle.h"
+#include "qsynthDialVokiStyle.h"
+#include "qsynthDialPeppinoStyle.h"
+
 #include <QApplication>
 #include <QSocketNotifier>
 #include <QMessageBox>
@@ -485,6 +489,8 @@ qsynthMainForm::qsynthMainForm (
 	QObject::connect(m_ui.DeleteEngineToolButton,
 		SIGNAL(clicked()),
 		SLOT(deleteEngine()));
+
+	m_pKnobStyle = NULL;
 }
 
 
@@ -513,6 +519,9 @@ qsynthMainForm::~qsynthMainForm (void)
 
 	// Pseudo-singleton reference shut-down.
 	g_pMainForm = NULL;
+	
+	if (m_pKnobStyle)
+		delete m_pKnobStyle;
 }
 
 
@@ -548,6 +557,9 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 	m_pMessagesForm = new qsynthMessagesForm(pParent, wflags);
 	m_pChannelsForm = new qsynthChannelsForm(pParent, wflags);
 
+	// Setup appropriately...
+	m_pMessagesForm->setLogging(m_pOptions->bMessagesLog, m_pOptions->sMessagesLogPath);
+
 	// Get the default setup and dummy instace tab.
 	m_ui.TabBar->addEngine(new qsynthEngine(m_pOptions));
 	// And all additional custom ones...
@@ -568,6 +580,9 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 	updateOutputMeters();
 	updateSystemTray();
 
+	// Knobs
+	updateKnobs();
+	
 #if !defined(WIN32)
 	// Check if we can redirect our own stdout/stderr...
 	if (m_pOptions->bStdoutCapture && ::pipe(g_fdStdout) == 0) {
@@ -1319,13 +1334,18 @@ void qsynthMainForm::showOptionsForm (void)
 		if (m_pOptions->sMessagesFont.isEmpty() && m_pMessagesForm)
 			m_pOptions->sMessagesFont = m_pMessagesForm->messagesFont().toString();
 		// To track down deferred or immediate changes.
+		bool    bOldMessagesLog = m_pOptions->bMessagesLog; 
+		QString sOldMessagesLogPath = m_pOptions->sMessagesLogPath;
 		QString sMessagesFont  = m_pOptions->sMessagesFont;
 		bool    bSystemTray    = m_pOptions->bSystemTray;
 		bool    bOutputMeters  = m_pOptions->bOutputMeters;
 		bool    bStdoutCapture = m_pOptions->bStdoutCapture;
 		bool    bKeepOnTop     = m_pOptions->bKeepOnTop;
+		int     iOldBaseFontSize = m_pOptions->iBaseFontSize;
 		int     bMessagesLimit = m_pOptions->bMessagesLimit;
 		int     iMessagesLimitLines = m_pOptions->iMessagesLimitLines;
+		int     iKnobStyle     = m_pOptions->iKnobStyle;
+		int     iKnobMotion    = m_pOptions->iKnobMotion;
 		// Load the current setup settings.
 		pOptionsForm->setup(m_pOptions);
 		// Show the setup dialog...
@@ -1334,13 +1354,19 @@ void qsynthMainForm::showOptionsForm (void)
 			if (( bStdoutCapture && !m_pOptions->bStdoutCapture) ||
 				(!bStdoutCapture &&  m_pOptions->bStdoutCapture) ||
 				( bKeepOnTop     && !m_pOptions->bKeepOnTop)     ||
-				(!bKeepOnTop     &&  m_pOptions->bKeepOnTop)) {
+				(!bKeepOnTop     &&  m_pOptions->bKeepOnTop)     ||
+				(iOldBaseFontSize != m_pOptions->iBaseFontSize)) {
 				QMessageBox::information(this,
 					QSYNTH_TITLE ": " + tr("Information"),
 					tr("Some settings will be only effective\n"
 					"next time you start this program."), tr("OK"));
 			}
 			// Check wheather something immediate has changed.
+			if (( bOldMessagesLog && !m_pOptions->bMessagesLog) ||
+				(!bOldMessagesLog &&  m_pOptions->bMessagesLog) ||
+				(sOldMessagesLogPath != m_pOptions->sMessagesLogPath))
+				m_pMessagesForm->setLogging(
+					m_pOptions->bMessagesLog, m_pOptions->sMessagesLogPath);
 			if (sMessagesFont != m_pOptions->sMessagesFont)
 				updateMessagesFont();
 			if (( bMessagesLimit && !m_pOptions->bMessagesLimit) ||
@@ -1350,6 +1376,9 @@ void qsynthMainForm::showOptionsForm (void)
 			if (( bSystemTray && !m_pOptions->bSystemTray) ||
 				(!bSystemTray &&  m_pOptions->bSystemTray))
 				updateSystemTray();
+			if (( iKnobStyle != m_pOptions->iKnobStyle) ||
+				( iKnobMotion != m_pOptions->iKnobMotion))
+				updateKnobs();
 			// There's some option(s) that need a global restart...
 			if (( bOutputMeters  && !m_pOptions->bOutputMeters) ||
 				(!bOutputMeters  &&  m_pOptions->bOutputMeters)) {
@@ -1876,6 +1905,13 @@ void qsynthMainForm::stopEngine ( qsynthEngine *pEngine )
 }
 
 
+// Start all synth engines (schedule).
+void qsynthMainForm::startAllEngines (void)
+{
+	m_iTimerDelay = 0;
+}
+
+
 // Restart all synth engines.
 void qsynthMainForm::restartAllEngines (void)
 {
@@ -1897,7 +1933,7 @@ void qsynthMainForm::restartAllEngines (void)
 		// Must make this one grayed out for a while...
 		m_ui.RestartPushButton->setEnabled(false);
 		// And making room for immediate restart...
-		m_iTimerDelay = 0;
+		startAllEngines();
 	}
 }
 
@@ -1928,7 +1964,7 @@ void qsynthMainForm::restartEngine ( qsynthEngine *pEngine )
 		// Restarting means stopping the engine...
 		stopEngine(pEngine);
 		// And making room for immediate restart...
-		m_iTimerDelay = 0;
+		startAllEngines();
 	}
 }
 
@@ -2343,4 +2379,35 @@ void qsynthMainForm::contextMenuEvent( QContextMenuEvent *pEvent )
 }
 
 
+void qsynthMainForm::updateKnobs()
+{
+	if (m_pOptions == NULL)
+		return;	
+	qsynthKnob::DialMode mode = qsynthKnob::DialMode(m_pOptions->iKnobMotion);
+	KnobStyle style = KnobStyle(m_pOptions->iKnobStyle); 
+	if (m_pKnobStyle) {
+		delete m_pKnobStyle;
+	}
+	switch (style) {
+	case Classic:
+		m_pKnobStyle = new qsynthDialClassicStyle();
+		break;
+	case Vokimon:
+		m_pKnobStyle = new qsynthDialVokiStyle();
+		break;
+	case Peppino:
+		m_pKnobStyle = new qsynthDialPeppinoStyle();
+		break;
+	default:
+		m_pKnobStyle = NULL;
+		break;
+	}
+	QList<qsynthKnob *> allKnobs = findChildren<qsynthKnob *>();
+	foreach(qsynthKnob* knob, allKnobs) {
+		knob->setStyle(m_pKnobStyle);
+		knob->setDialMode(mode);
+	}
+}
+
+
 // end of qsynthMainForm.cpp
