@@ -61,6 +61,8 @@ public:
 	bool deleteEngineTab(qsynthEngine *pEngine, int iTab);
 	bool setupEngineTab(qsynthEngine *pEngine, int iTab);
 
+	void startAllEngines();
+
 	bool startEngine(qsynthEngine *pEngine);
 	void stopEngine(qsynthEngine *pEngine);
 
@@ -68,6 +70,8 @@ public:
 	void restartEngine(qsynthEngine *pEngine);
 	void resetEngine(qsynthEngine *pEngine);
 
+	enum KnobStyle { Classic, Vokimon, Peppino, Legacy };
+	
 public slots:
 
 	void stdoutNotifySlot(int);
@@ -150,6 +154,8 @@ protected:
 
 	void contextMenuEvent(QContextMenuEvent *pEvent);
 
+	void updateKnobs();
+
 private:
 
 	// The Qt-designer UI struct...
@@ -182,6 +188,9 @@ private:
 
 	// Kind-of singleton reference.
 	static qsynthMainForm *g_pMainForm;
+	
+	// Style for qsynthKnob (QDial) widgets 
+	QStyle* m_pKnobStyle;
 };
 
 
