@@ -1,8 +1,7 @@
 // qsynthOptions.cpp
-// qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,6 +25,7 @@
 #include "qsynthEngine.h"
 
 #include <QTextStream>
+#include <QComboBox>
 
 
 //-------------------------------------------------------------------------
@@ -46,12 +46,17 @@ qsynthOptions::qsynthOptions (void)
 	sMessagesFont   = m_settings.value("/MessagesFont").toString();
 	bMessagesLimit  = m_settings.value("/MessagesLimit", true).toBool();
 	iMessagesLimitLines = m_settings.value("/MessagesLimitLines", 1000).toInt();
+	bMessagesLog    = m_settings.value("/MessagesLog", false).toBool();
+	sMessagesLogPath = m_settings.value("/MessagesLogPath", "qsynth.log").toString();
 	bQueryClose     = m_settings.value("/QueryClose", true).toBool();
 	bKeepOnTop      = m_settings.value("/KeepOnTop", false).toBool();
 	bStdoutCapture  = m_settings.value("/StdoutCapture", true).toBool();
 	bOutputMeters   = m_settings.value("/OutputMeters", false).toBool();
 	bSystemTray     = m_settings.value("/SystemTray", false).toBool();
 	bStartMinimized = m_settings.value("/StartMinimized", false).toBool();
+	iBaseFontSize   = m_settings.value("/BaseFontSize", 0).toInt();
+	iKnobStyle      = m_settings.value("/KnobStyle", 0).toInt();
+	iKnobMotion     = m_settings.value("/KnobMotion", 1).toInt();
 	m_settings.endGroup();
 
 	// Load defaults...
@@ -106,12 +111,17 @@ qsynthOptions::~qsynthOptions (void)
 	m_settings.setValue("/MessagesFont", sMessagesFont);
 	m_settings.setValue("/MessagesLimit", bMessagesLimit);
 	m_settings.setValue("/MessagesLimitLines", iMessagesLimitLines);
+	m_settings.setValue("/MessagesLog", bMessagesLog);
+	m_settings.setValue("/MessagesLogPath", sMessagesLogPath);
 	m_settings.setValue("/QueryClose", bQueryClose);
 	m_settings.setValue("/KeepOnTop", bKeepOnTop);
 	m_settings.setValue("/StdoutCapture", bStdoutCapture);
 	m_settings.setValue("/OutputMeters", bOutputMeters);
 	m_settings.setValue("/SystemTray", bSystemTray);
 	m_settings.setValue("/StartMinimized", bStartMinimized);
+	m_settings.setValue("/BaseFontSize", iBaseFontSize);
+	m_settings.setValue("/KnobStyle", iKnobStyle);
+	m_settings.setValue("/KnobMotion", iKnobMotion);
 	m_settings.endGroup();
 
 	// Create default setup descriptor.
@@ -474,19 +484,26 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	m_settings.beginGroup("/Settings");
 	pSetup->sDisplayName     = m_settings.value("/DisplayName", sDisplayName).toString();
 	pSetup->bMidiIn          = m_settings.value("/MidiIn", true).toBool();
+#if defined(WIN32)
+	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "winmidi").toString();
+    pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
+    pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
+    pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 8).toInt();
+#else
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "alsa_seq").toString();
+    pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
+    pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 64).toInt();
+    pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
+#endif
+    pSetup->sAlsaName        = m_settings.value("/AlsaName", "pid").toString();
+    pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
+    pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
+    pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
 	pSetup->sMidiDevice      = m_settings.value("/MidiDevice").toString();
 	pSetup->iMidiChannels    = m_settings.value("/MidiChannels", 16).toInt();
-	pSetup->sAlsaName        = m_settings.value("/AlsaName", "pid").toString();
-	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
 	pSetup->sAudioDevice     = m_settings.value("/AudioDevice").toString();
-	pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
-	pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
-	pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
 	pSetup->iAudioChannels   = m_settings.value("/AudioChannels", 1).toInt();
 	pSetup->iAudioGroups     = m_settings.value("/AudioGroups", 1).toInt();
-	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 64).toInt();
-	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
 	pSetup->sSampleFormat    = m_settings.value("/SampleFormat", "16bits").toString();
 	pSetup->fSampleRate      = m_settings.value("/SampleRate", 44100.0).toDouble();
 	pSetup->iPolyphony       = m_settings.value("/Polyphony", 256).toInt();
@@ -756,6 +773,62 @@ bool qsynthOptions::deletePreset ( qsynthEngine *pEngine, const QString& sPreset
 }
 
 
+//---------------------------------------------------------------------------
+// Combo box history persistence helper implementation.
+
+void qsynthOptions::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
+{
+	// Load combobox list from configuration settings file...
+	m_settings.beginGroup("/History/" + pComboBox->objectName());
+
+	if (m_settings.childKeys().count() > 0) {
+		pComboBox->setUpdatesEnabled(false);
+		pComboBox->setDuplicatesEnabled(false);
+		pComboBox->clear();
+		for (int i = 0; i < iLimit; i++) {
+			const QString& sText = m_settings.value(
+				"/Item" + QString::number(i + 1)).toString();
+			if (sText.isEmpty())
+				break;
+			pComboBox->addItem(sText);
+		}
+		pComboBox->setUpdatesEnabled(true);
+	}
+
+	m_settings.endGroup();
+}
+
+
+void qsynthOptions::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
+{
+	// Add current text as latest item...
+	const QString& sCurrentText = pComboBox->currentText();
+	int iCount = pComboBox->count();
+	for (int i = 0; i < iCount; i++) {
+		const QString& sText = pComboBox->itemText(i);
+		if (sText == sCurrentText) {
+			pComboBox->removeItem(i);
+			iCount--;
+			break;
+		}
+	}
+	while (iCount >= iLimit)
+		pComboBox->removeItem(--iCount);
+	pComboBox->insertItem(0, sCurrentText);
+	iCount++;
+
+	// Save combobox list to configuration settings file...
+	m_settings.beginGroup("/History/" + pComboBox->objectName());
+	for (int i = 0; i < iCount; i++) {
+		const QString& sText = pComboBox->itemText(i);
+		if (sText.isEmpty())
+			break;
+		m_settings.setValue("/Item" + QString::number(i + 1), sText);
+	}
+	m_settings.endGroup();
+}
+
+
 //---------------------------------------------------------------------------
 // Widget geometry persistence helper methods.
 
