@@ -1,7 +1,7 @@
 // qsynthOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,7 +24,8 @@
 
 #include "qsynthSetup.h"
 
-#include <QComboBox>
+// Forward declarations.
+class QComboBox;
 
 
 //-------------------------------------------------------------------------
@@ -55,12 +56,17 @@ public:
 	QString sMessagesFont;
 	bool    bMessagesLimit;
 	int     iMessagesLimitLines;
+	bool    bMessagesLog;
+	QString sMessagesLogPath;
 	bool    bQueryClose;
 	bool    bKeepOnTop;
 	bool    bStdoutCapture;
 	bool    bOutputMeters;
 	bool    bSystemTray;
 	bool    bStartMinimized;
+	int     iBaseFontSize;
+	int     iKnobStyle;
+	int     iKnobMotion;
 
 	// Default options...
 	QString sSoundFontDir;
@@ -83,6 +89,10 @@ public:
 	bool savePreset(qsynthEngine *pEngine, const QString& sPreset);
 	bool deletePreset(qsynthEngine *pEngine, const QString& sPreset);
 
+	// Combo box history persistence helper prototypes.
+	void loadComboBoxHistory(QComboBox *pComboBox, int iLimit = 8);
+	void saveComboBoxHistory(QComboBox *pComboBox, int iLimit = 8);
+
 	// Widget geometry persistence helper prototypes.
 	void saveWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
 	void loadWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
