@@ -1,7 +1,7 @@
 // qsynthOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 #include <QValidator>
 #include <QMessageBox>
 #include <QFontDialog>
+#include <QFileDialog>
 
 
 //----------------------------------------------------------------------------
@@ -57,6 +58,15 @@ qsynthOptionsForm::qsynthOptionsForm (
 	QObject::connect(m_ui.MessagesFontPushButton,
 		SIGNAL(clicked()),
 		SLOT(chooseMessagesFont()));
+	QObject::connect(m_ui.MessagesLogCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.MessagesLogPathComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.MessagesLogPathToolButton,
+		SIGNAL(clicked()),
+		SLOT(browseMessagesLogPath()));
 	QObject::connect(m_ui.QueryCloseCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -75,12 +85,21 @@ qsynthOptionsForm::qsynthOptionsForm (
 	QObject::connect(m_ui.StartMinimizedCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.BaseFontSizeComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.MessagesLimitCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
 	QObject::connect(m_ui.MessagesLimitLinesComboBox,
 		SIGNAL(activated(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.KnobStyleComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.KnobMouseMotionComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.OkPushButton,
 		SIGNAL(clicked()),
 		SLOT(accept()));
@@ -107,6 +126,9 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 	// Avoid nested changes.
 	m_iDirtySetup++;
 
+	// Load combo box history...
+	m_pOptions->loadComboBoxHistory(m_ui.MessagesLogPathComboBox);
+
 	// Load Display options...
 	QFont font;
 	// Messages font.
@@ -125,6 +147,10 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 	m_ui.MessagesLimitLinesComboBox->setEditText(
 		QString::number(m_pOptions->iMessagesLimitLines));
 
+	// Logging options
+	m_ui.MessagesLogCheckBox->setChecked(m_pOptions->bMessagesLog);
+	m_ui.MessagesLogPathComboBox->setEditText(m_pOptions->sMessagesLogPath);
+
 	// Other options finally.
 	m_ui.QueryCloseCheckBox->setChecked(m_pOptions->bQueryClose);
 	m_ui.KeepOnTopCheckBox->setChecked(m_pOptions->bKeepOnTop);
@@ -132,6 +158,16 @@ void qsynthOptionsForm::setup ( qsynthOptions *pOptions )
 	m_ui.OutputMetersCheckBox->setChecked(m_pOptions->bOutputMeters);
 	m_ui.SystemTrayCheckBox->setChecked(m_pOptions->bSystemTray);
 	m_ui.StartMinimizedCheckBox->setChecked(m_pOptions->bStartMinimized);
+	if (m_pOptions->iBaseFontSize > 0) {
+		m_ui.BaseFontSizeComboBox->setEditText(
+			QString::number(m_pOptions->iBaseFontSize));
+	} else {
+		m_ui.BaseFontSizeComboBox->setCurrentIndex(0);
+	}
+
+	// Knobs
+	m_ui.KnobStyleComboBox->setCurrentIndex(m_pOptions->iKnobStyle);
+	m_ui.KnobMouseMotionComboBox->setCurrentIndex(m_pOptions->iKnobMotion);
 
 #if defined(WIN32)
 	m_ui.StdoutCaptureCheckBox->setChecked(false);
@@ -159,16 +195,25 @@ void qsynthOptionsForm::accept (void)
 		m_pOptions->sMessagesFont   = m_ui.MessagesFontTextLabel->font().toString();
 		m_pOptions->bMessagesLimit  = m_ui.MessagesLimitCheckBox->isChecked();
 		m_pOptions->iMessagesLimitLines = m_ui.MessagesLimitLinesComboBox->currentText().toInt();
+		m_pOptions->bMessagesLog    = m_ui.MessagesLogCheckBox->isChecked();
+		m_pOptions->sMessagesLogPath = m_ui.MessagesLogPathComboBox->currentText();
 		m_pOptions->bQueryClose     = m_ui.QueryCloseCheckBox->isChecked();
 		m_pOptions->bKeepOnTop      = m_ui.KeepOnTopCheckBox->isChecked();
 		m_pOptions->bStdoutCapture  = m_ui.StdoutCaptureCheckBox->isChecked();
 		m_pOptions->bOutputMeters   = m_ui.OutputMetersCheckBox->isChecked();
 		m_pOptions->bSystemTray     = m_ui.SystemTrayCheckBox->isChecked();
 		m_pOptions->bStartMinimized = m_ui.StartMinimizedCheckBox->isChecked();
+		m_pOptions->iBaseFontSize   = m_ui.BaseFontSizeComboBox->currentText().toInt();
+		// Knobs
+		m_pOptions->iKnobStyle      = m_ui.KnobStyleComboBox->currentIndex();
+		m_pOptions->iKnobMotion     = m_ui.KnobMouseMotionComboBox->currentIndex();
 		// Reset dirty flag.
 		m_iDirtyCount = 0;
 	}
 
+	// Save combobox history...
+	m_pOptions->saveComboBoxHistory(m_ui.MessagesLogPathComboBox);
+
 	// Just go with dialog acceptance.
 	QDialog::accept();
 }
@@ -215,13 +260,41 @@ void qsynthOptionsForm::optionsChanged()
 // Stabilize current form state.
 void qsynthOptionsForm::stabilizeForm()
 {
+	bool bValid = (m_iDirtyCount > 0);
+
 	m_ui.MessagesLimitLinesComboBox->setEnabled(
 		m_ui.MessagesLimitCheckBox->isChecked());
 
+	bool bEnabled = m_ui.MessagesLogCheckBox->isChecked();
+	m_ui.MessagesLogPathComboBox->setEnabled(bEnabled);
+	m_ui.MessagesLogPathToolButton->setEnabled(bEnabled);
+	if (bEnabled && bValid) {
+		const QString& sPath = m_ui.MessagesLogPathComboBox->currentText();
+		bValid = !sPath.isEmpty();
+	}
+
 	m_ui.StartMinimizedCheckBox->setEnabled(
 		m_ui.SystemTrayCheckBox->isChecked());
 
-	m_ui.OkPushButton->setEnabled(m_iDirtyCount > 0);
+	m_ui.OkPushButton->setEnabled(bValid);
+}
+
+
+// Messages log path browse slot.
+void qsynthOptionsForm::browseMessagesLogPath()
+{
+	QString sFileName = QFileDialog::getSaveFileName(
+		this,											// Parent.
+		tr("Messages Log"),				                // Caption.
+		m_ui.MessagesLogPathComboBox->currentText(),	// Start here.
+		tr("Log files") + " (*.log)"	                // Filter (log files)
+	);
+
+	if (!sFileName.isEmpty()) {
+		m_ui.MessagesLogPathComboBox->setEditText(sFileName);
+		m_ui.MessagesLogPathComboBox->setFocus();
+		optionsChanged();
+	}
 }
 
 
